<?php
/*
Plugin Name: Top Post From Category Widget
Plugin URI: http://cjyabraham.com/projects/top-post-from-category-plugin/
Description: Sidebar widget that shows the top post from a particular category plus its thumbnail.  The excerpt from the post can be overridden.
Author: Chris Abraham
Version: 0.2
Author URI: http://cjyabraham.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St - 5th Floor, Boston, MA  02110-1301, USA.

*/

/* Sidebar Widget */

function widget_toppostfromcategory($args) {

extract($args);
$options = get_option('toppostfromcategory');
$category = $options['category'];
$excerpt = $options['excerpt'];

if (is_home())
{
  $title = empty($options['title']) ? __('Top Post from Category') : $options['title'];

  # since this widget special style needs, we override the default
  # $before_widget value set in functions.php
  $before_widget = '<div class="widget" id="top-post">';

  echo $before_widget;
  echo $before_title . $title . $after_title;

  $my_query = new WP_Query("cat=$category&showposts=1");
  $my_query->the_post();

  $thumb = get_the_thumb();
  ?>
  <div class="post">
     <h4 class="post-title"><a href="<?php the_permalink(); ?>"> <?php the_title(); ?> </a></h4>
     <span class="byline">by  <?php the_author_posts_link(); ?></span>
     <?php if ($thumb){ ?>
     <div class="thumbnail"><img src="<?php echo $thumb; ?>" alt="<?php the_title(); ?>" /></div>
     <?php } ?>
     <p class="post-entry">
     <?php
     if ($excerpt)
       echo $excerpt;
     else
       the_excerpt_rss();
     ?>
   <a href="<?php the_permalink(); ?>">more &raquo;</a></p>
   </div>

  <?php
  echo $after_widget;
}
}

function get_the_thumb() { //always inside the loop
  global $post;

  $attargs = array(
                   'post_type' => 'attachment',
                   'numberposts' => null,
                   'post_status' => null,
                   'post_parent' => $post->ID
                   );
  $attachments = get_posts($attargs);
  if ($attachments)
    return wp_get_attachment_thumb_url($attachments[0]->ID);

  return '';
}


function widget_toppostfromcategory_control() {
  // Get our options and see if we're handling a form submission.
  $options = get_option('toppostfromcategory');
  if ( !is_array($options) )
    $options = array('title'=>'Top Post from Category', 'heading_text'=>__('Top Post', 'widgets'));

  if ( $_POST['toppostfromcategory-submit'] ) {
    // Remember to sanitize and format use input appropriately.
    $options['title'] = strip_tags(stripslashes($_POST['toppostfromcategory-title']));
    $options['category'] = strip_tags(stripslashes($_POST['toppostfromcategory-category']));
    $options['excerpt'] = stripslashes($_POST['toppostfromcategory-excerpt']);
    update_option('toppostfromcategory', $options);
  }

  if (!$options['title'])
    $options['title'] = 'Top Post from Category';

  // Be sure you format your options to be valid HTML attributes.
  $title = htmlspecialchars($options['title'], ENT_QUOTES);
  $category = htmlspecialchars($options['category'], ENT_QUOTES);
  $excerpt = stripslashes($options['excerpt']);

  // Here is our little form segment. Notice that we don't need a
  // complete form. This will be embedded into the existing form.
  ?>
    <p style="text-align:right;">
       <label for="toppostfromcategory-title"><?php echo __('Title:'); ?>
       <input style="width: 200px;" id="toppostfromcategory-title" name="toppostfromcategory-title" type="text" value="<?php echo $title; ?>" />
        </label>
    </p>
    <p style="text-align:right;">
       <label for="toppostfromcategory-category"><?php echo __('Category ID:', 'widgets'); ?>
       <input style="width: 60px;" id="toppostfromcategory-category" name="toppostfromcategory-category" type="text" value="<?php echo $category; ?>" />
       </label>
    </p>
    <p style="text-align:left;">
       <label for="toppostfromcategory-excerpt"><?php echo __('Excerpt:'); ?>
       <textarea style="width: 100%; height: 150px;" id="toppostfromcategory-excerpt" name="toppostfromcategory-excerpt"><?php echo $excerpt; ?></textarea>
        </label>
    </p>
    <input type="hidden" id="toppostfromcategory-submit" name="toppostfromcategory-submit" value="1" />
<?php
}

function tpfc_init()
{
  if ( !function_exists('register_sidebar_widget') )
    return;

  register_sidebar_widget(array("Top Post from Category", 'widgets'), 'widget_toppostfromcategory');
  register_widget_control(array("Top Post from Category", 'widgets'), 'widget_toppostfromcategory_control');

}

add_action('widgets_init', 'tpfc_init');

?>